==> wiki3_5_1.zip: wiki3_5_1/plugin/core/Include.pm <==
######################################################################
#
# ꤷڡ⤷ϻڡλѥ饰դ򥤥󥯥롼ɤޤ
# ڡΤ򥤥󥯥롼ɤϰ˥ڡ̾ꤷޤ
# <pre>
# {{include ڡ̾}}
# </pre>
# ڡΥѥ饰դ򥤥󥯥롼ɤ
# ڡ̾³裲˥ѥ饰̾ꤷޤ
# <pre>
# {{include ڡ̾,ѥ饰̾}}
# </pre>
#
######################################################################
package plugin::core::Include;
#use strict;
#=====================================================================
# 󥹥ȥ饯
#=====================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#=====================================================================
# ѥ饰մؿ
#=====================================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $page   = shift;
	my $para   = shift;
	my $cgi    = $wiki->get_CGI;
	
	if($page eq ""){
		return &Util::paragraph_error("ڡꤵƤޤ","WIKI");
	}
	if(!$wiki->page_exists($page)){
		return &Util::paragraph_error("ڡ¸ߤޤ","WIKI");
	}
	if(!$wiki->can_show($page)){
		return &Util::paragraph_error("ڡλȸ¤ޤ","WIKI");
	}
	if($page eq $cgi->param("page")){
		return &Util::paragraph_error("ƱΥڡincludeǤޤ","WIKI");
	}
	foreach my $incpage (@{$self->{stack}}){
		if($incpage eq $page){
			return &Util::paragraph_error("ƱΥڡincludeǤޤ","WIKI");
		}
	}
	
	my $source = $wiki->get_page($page);
	
	$para = quotemeta(Util::trim($para));
	if($para ne ""){
		if($source =~ /(\n|^)!!!\s*$para\s*\n((.|\s|\r|\n)*?)\s*(\n!!!|$)/){
			$source = $2;
		} elsif($source =~ /(\n|^)!!\s*$para\s*\n((.|\s|\r|\n)*?)\s*(\n!!|$)/){
			$source = $2;
		} elsif($source =~ /(\n|^)!\s*$para\s*\n((.|\s|\r|\n)*?)\s*(\n!|$)/){
			$source = $2;
		} else {
			return &Util::paragraph_error("ڡ¸ߤޤ","WIKI");
		}
	}
	
	# åˤĤ
	push(@{$self->{stack}},$page);
	
	# ä΢
	my $pagetmp = $cgi->param("page");
	$cgi->param("page",$page);
	$self->{parser}->parse($source);
	$cgi->param("page",$pagetmp);
	
	# å
	pop(@{$self->{stack}});
	
	return undef;
}

1;

==> wiki3_5_5.zip: wiki3_5_5/plugin/core/Include.pm <==
###############################################################################
#
# <p>ꤷڡ⤷ϻڡλѥ饰դ򥤥󥯥롼ɤޤ</p>
# <p>
#   ڡΤ򥤥󥯥롼ɤϰ˥ڡ̾ꤷޤ
# </p>
# <pre>
# {{include ڡ̾}}
# </pre>
# <p>
#   ڡΥѥ饰դ򥤥󥯥롼ɤ
#   ڡ̾³裲˥ѥ饰̾ꤷޤ
# </p>
# <pre>
# {{include ڡ̾,ѥ饰̾}}
# </pre>
#
###############################################################################
package plugin::core::Include;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ѥ饰մؿ
#==============================================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $page   = shift;
	my $para   = shift;
	my $cgi    = $wiki->get_CGI;
	
	# 顼å
	if($page eq ""){
		return &Util::paragraph_error("ڡꤵƤޤ","WIKI");
	}
	if(!$wiki->page_exists($page)){
		return &Util::paragraph_error("ڡ¸ߤޤ","WIKI");
	}
	if(!$wiki->can_show($page)){
		return &Util::paragraph_error("ڡλȸ¤ޤ","WIKI");
	}
	if($page eq $cgi->param("page")){
		return &Util::paragraph_error("ƱΥڡincludeǤޤ","WIKI");
	}
	foreach my $incpage (@{$self->{stack}}){
		if($incpage eq $page){
			return &Util::paragraph_error("ƱΥڡincludeǤޤ","WIKI");
		}
	}
	
	# 
	my $source = $wiki->get_page($page);
	
	# ѥ饰դꤵƤϥѥ饰դڤФ
	$para = quotemeta(Util::trim($para));
	if($para ne ""){
		if($source =~ /(\n|^)!!!\s*$para\s*\n((.|\s|\r|\n)*?)\s*(\n!!!|$)/){
			$source = $2;
		} elsif($source =~ /(\n|^)!!\s*$para\s*\n((.|\s|\r|\n)*?)\s*(\n!!|$)/){
			$source = $2;
		} elsif($source =~ /(\n|^)!\s*$para\s*\n((.|\s|\r|\n)*?)\s*(\n!|$)/){
			$source = $2;
		} else {
			return &Util::paragraph_error("ڡ¸ߤޤ","WIKI");
		}
	}
	
	# åˤĤ̵¥롼ɻѡ
	push(@{$self->{stack}},$page);
	
	# ä΢
	my $pagetmp = $cgi->param("page");
	$cgi->param("page",$page);
	$self->{parser}->parse($source);
	$cgi->param("page",$pagetmp);
	
	# å
	pop(@{$self->{stack}});
	
	return undef;
}

1;
